@@ -255,7 +255,7 @@ pub fn init(args: &str, output_indicator: u16) -> Result<(), SetLoggerError> {
             .get_feature_info()
             .map_or(false, |finfo| finfo.has_tsc());
         LOGGER.has_invariant_tsc = cpuid
-            .get_extended_function_info()
+            .get_advanced_power_mgmt_info()
             .map_or(false, |efinfo| efinfo.has_invariant_tsc());
 
         if LOGGER.has_tsc {
